# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ProviderMfaRequestMethod(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    SMS = "sms"
    EMAIL = "email"

    def visit(self, sms: typing.Callable[[], T_Result], email: typing.Callable[[], T_Result]) -> T_Result:
        if self is ProviderMfaRequestMethod.SMS:
            return sms()
        if self is ProviderMfaRequestMethod.EMAIL:
            return email()
