# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class BulkOpType(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    LINK_BULK_IMPORT = "link_bulk_import"
    LINK_BULK_HISTORICAL_TRIGGER = "link_bulk_historical_trigger"

    def visit(
        self,
        link_bulk_import: typing.Callable[[], T_Result],
        link_bulk_historical_trigger: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is BulkOpType.LINK_BULK_IMPORT:
            return link_bulk_import()
        if self is BulkOpType.LINK_BULK_HISTORICAL_TRIGGER:
            return link_bulk_historical_trigger()
