# This file was auto-generated by Fern from our API Definition.

import typing

from .date_part_expr import DatePartExpr
from .date_trunc_expr import DateTruncExpr

QueryGroupByItem = typing.Union[DateTruncExpr, DatePartExpr]
