# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LabTestStatus(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    ACTIVE = "active"
    PENDING_APPROVAL = "pending_approval"
    INACTIVE = "inactive"

    def visit(
        self,
        active: typing.Callable[[], T_Result],
        pending_approval: typing.Callable[[], T_Result],
        inactive: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is LabTestStatus.ACTIVE:
            return active()
        if self is LabTestStatus.PENDING_APPROVAL:
            return pending_approval()
        if self is LabTestStatus.INACTIVE:
            return inactive()
