# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OrderActivationType(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    CURRENT = "current"
    SCHEDULED = "scheduled"

    def visit(self, current: typing.Callable[[], T_Result], scheduled: typing.Callable[[], T_Result]) -> T_Result:
        if self is OrderActivationType.CURRENT:
            return current()
        if self is OrderActivationType.SCHEDULED:
            return scheduled()
