# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingWheelchairPushChangedEventType(str, enum.Enum):
    DAILY_DATA_WHEELCHAIR_PUSH_CREATED = "daily.data.wheelchair_push.created"
    DAILY_DATA_WHEELCHAIR_PUSH_UPDATED = "daily.data.wheelchair_push.updated"

    def visit(
        self,
        daily_data_wheelchair_push_created: typing.Callable[[], T_Result],
        daily_data_wheelchair_push_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingWheelchairPushChangedEventType.DAILY_DATA_WHEELCHAIR_PUSH_CREATED:
            return daily_data_wheelchair_push_created()
        if self is ClientFacingWheelchairPushChangedEventType.DAILY_DATA_WHEELCHAIR_PUSH_UPDATED:
            return daily_data_wheelchair_push_updated()
