# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LabTestGenerationMethodFilter(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    AUTO = "auto"
    MANUAL = "manual"
    ALL = "all"

    def visit(
        self,
        auto: typing.Callable[[], T_Result],
        manual: typing.Callable[[], T_Result],
        all_: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is LabTestGenerationMethodFilter.AUTO:
            return auto()
        if self is LabTestGenerationMethodFilter.MANUAL:
            return manual()
        if self is LabTestGenerationMethodFilter.ALL:
            return all_()
