# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Availability(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    AVAILABLE = "available"
    UNAVAILABLE = "unavailable"

    def visit(self, available: typing.Callable[[], T_Result], unavailable: typing.Callable[[], T_Result]) -> T_Result:
        if self is Availability.AVAILABLE:
            return available()
        if self is Availability.UNAVAILABLE:
            return unavailable()
