# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class MarkerType(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    BIOMARKER = "biomarker"
    PANEL = "panel"

    def visit(self, biomarker: typing.Callable[[], T_Result], panel: typing.Callable[[], T_Result]) -> T_Result:
        if self is MarkerType.BIOMARKER:
            return biomarker()
        if self is MarkerType.PANEL:
            return panel()
