# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingAppointmentChangedEventType(str, enum.Enum):
    LABTEST_APPOINTMENT_CREATED = "labtest.appointment.created"
    LABTEST_APPOINTMENT_UPDATED = "labtest.appointment.updated"

    def visit(
        self,
        labtest_appointment_created: typing.Callable[[], T_Result],
        labtest_appointment_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingAppointmentChangedEventType.LABTEST_APPOINTMENT_CREATED:
            return labtest_appointment_created()
        if self is ClientFacingAppointmentChangedEventType.LABTEST_APPOINTMENT_UPDATED:
            return labtest_appointment_updated()
