# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingHeartRateRecoveryOneMinuteChangedEventType(str, enum.Enum):
    DAILY_DATA_HEART_RATE_RECOVERY_ONE_MINUTE_CREATED = "daily.data.heart_rate_recovery_one_minute.created"
    DAILY_DATA_HEART_RATE_RECOVERY_ONE_MINUTE_UPDATED = "daily.data.heart_rate_recovery_one_minute.updated"

    def visit(
        self,
        daily_data_heart_rate_recovery_one_minute_created: typing.Callable[[], T_Result],
        daily_data_heart_rate_recovery_one_minute_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if (
            self
            is ClientFacingHeartRateRecoveryOneMinuteChangedEventType.DAILY_DATA_HEART_RATE_RECOVERY_ONE_MINUTE_CREATED
        ):
            return daily_data_heart_rate_recovery_one_minute_created()
        if (
            self
            is ClientFacingHeartRateRecoveryOneMinuteChangedEventType.DAILY_DATA_HEART_RATE_RECOVERY_ONE_MINUTE_UPDATED
        ):
            return daily_data_heart_rate_recovery_one_minute_updated()
