# This file was auto-generated by Fern from our API Definition.

import typing

from .historical_pull_non_retriable_error_details import HistoricalPullNonRetriableErrorDetails
from .historical_pull_retriable_error_details import HistoricalPullRetriableErrorDetails

SingleHistoricalPullStatisticsErrorDetails = typing.Union[
    HistoricalPullRetriableErrorDetails, HistoricalPullNonRetriableErrorDetails
]
