# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class HomePregnancyTestEntryTestResult(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    NEGATIVE = "negative"
    POSITIVE = "positive"
    INDETERMINATE = "indeterminate"

    def visit(
        self,
        negative: typing.Callable[[], T_Result],
        positive: typing.Callable[[], T_Result],
        indeterminate: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is HomePregnancyTestEntryTestResult.NEGATIVE:
            return negative()
        if self is HomePregnancyTestEntryTestResult.POSITIVE:
            return positive()
        if self is HomePregnancyTestEntryTestResult.INDETERMINATE:
            return indeterminate()
