# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingElectrocardiogramInconclusiveCause(str, enum.Enum):
    HIGH_HEART_RATE = "high_heart_rate"
    LOW_HEART_RATE = "low_heart_rate"
    POOR_READING = "poor_reading"

    def visit(
        self,
        high_heart_rate: typing.Callable[[], T_Result],
        low_heart_rate: typing.Callable[[], T_Result],
        poor_reading: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingElectrocardiogramInconclusiveCause.HIGH_HEART_RATE:
            return high_heart_rate()
        if self is ClientFacingElectrocardiogramInconclusiveCause.LOW_HEART_RATE:
            return low_heart_rate()
        if self is ClientFacingElectrocardiogramInconclusiveCause.POOR_READING:
            return poor_reading()
