# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Select(str, enum.Enum):
    SELECT_ALL = "*"

    def visit(self, select_all: typing.Callable[[], T_Result]) -> T_Result:
        if self is Select.SELECT_ALL:
            return select_all()
