# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .ao_e import AoE
from .marker_type import MarkerType


class ClientFacingMarker(UniversalBaseModel):
    id: int
    name: str
    slug: str
    description: typing.Optional[str] = None
    lab_id: typing.Optional[int] = None
    provider_id: typing.Optional[str] = None
    type: typing.Optional[MarkerType] = None
    unit: typing.Optional[str] = None
    price: typing.Optional[str] = None
    aoe: typing.Optional[AoE] = None
    a_la_carte_enabled: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
